@@ -1,3 +1,3 @@
-from tankerkoenig.client import Client
+from tankerkoenig.client import Client, SortingMethod, Petrol
 from tankerkoenig import models
 from tankerkoenig import exceptions
